package com.myco.jmstest;

import java.io.File;
import java.io.FileReader;
import java.io.IOException;
import java.util.Properties;

import org.apache.log4j.PropertyConfigurator;
import org.hornetq.core.logging.Logger;
import org.hornetq.integration.logging.Log4jLogDelegateFactory;
import org.springframework.context.support.ClassPathXmlApplicationContext;

public class SenderMain {

    private static String MSG = "HornetQ is an open source asynchronous messaging project from JBoss. It is an example of Message Oriented Middleware. "
            + "HornetQ is an open source project to build a multi-protocol, embeddable, very high performance, clustered, asynchronous messaging system. "
            + "The HornetQ project was the brain-child of Tim Fox, and was launched on 24 August 2009, during much of its development the HornetQ code-base "
            + "was developed under the name JBoss Messaging 2.0. The HornetQ project is licensed using the Apache Software License v 2.0. Tim Fox led the "
            + "project until HornetQ 8 October 2010, when he stepped down as project lead to pursue other projects. HornetQ is currently led by Clebert "
            + "Suconic with core engineers Andy Taylor, Howard Gao and Jeff Mesnil. As of 4-2-2010 HornetQ is the SPECjms2007 record breaker.";
    
    public static void main(String[] args) throws InterruptedException {

        org.apache.log4j.Logger LOGGER = null;
        
        try {
            // get the default test log4j properties
            Properties log4jProperties = new Properties();
            log4jProperties.load(new FileReader(new File("cfg/log4j.properties")));
            PropertyConfigurator.configure(log4jProperties);
            
            LOGGER = org.apache.log4j.Logger.getLogger(SenderMain.class);
        } catch (IOException e) {
            // Just ignore it
            e.printStackTrace();
        }

        // open/read the application context file
        final ClassPathXmlApplicationContext context = new ClassPathXmlApplicationContext(
                "file:cfg/senderContext.xml");

        Logger.setDelegateFactory(new Log4jLogDelegateFactory());
        
        JmsSender sender = context.getBean(JmsSender.class);
        
        int messagesToSend = 10000000;
        LOGGER.info("Sending " + messagesToSend + " messages");
        for(int i = 0; i < messagesToSend; i++) {
            sender.sendMessage(MSG);
        }
        
        boolean sentAllMesages = false;
        for(int i = 0; i < 1000; i++) {
            if(sender.getTotalSent() == messagesToSend) {
                sentAllMesages = true;
                break;
            }
            Thread.sleep(1000);
        }
        
        if(sentAllMesages) {
            LOGGER.info("Finished sending all messages");
        } else {
            LOGGER.error("Was not able to send all messages");
        }
        sender.shutdown();
        
        // Shutdown
        context.close();
    }

}
